@@ -1,7 +1,7 @@
 #ifndef _LIBIPULOG_H
 #define _LIBIPULOG_H
 
-/* libipulog.h,v 1.4 2001/07/03 14:45:16 laforge Exp */
+/* $Id: libipulog.h,v 1.7 2003/05/04 10:00:10 laforge Exp $ */
 
 #include <errno.h>
 #include <unistd.h>
@@ -20,11 +20,11 @@
 #endif
 
 struct ipulog_handle;
-static int ipulog_errno;
+extern int ipulog_errno;
 
 u_int32_t ipulog_group2gmask(u_int32_t group);
 
-struct ipulog_handle *ipulog_create_handle(u_int32_t gmask);
+struct ipulog_handle *ipulog_create_handle(u_int32_t gmask, u_int32_t rmem);
 
 void ipulog_destroy_handle(struct ipulog_handle *h);
 
@@ -35,6 +35,24 @@ ulog_packet_msg_t *ipulog_get_packet(struct ipulog_handle *h,
 				     const unsigned char *buf,
 				     size_t len);
 
+char *ipulog_strerror(int errcode);
+
 void ipulog_perror(const char *s);
 
+enum 
+{
+	IPULOG_ERR_NONE = 0,
+	IPULOG_ERR_IMPL,
+	IPULOG_ERR_HANDLE,
+	IPULOG_ERR_SOCKET,
+	IPULOG_ERR_BIND,
+	IPULOG_ERR_RECVBUF,
+	IPULOG_ERR_RECV,
+	IPULOG_ERR_NLEOF,
+	IPULOG_ERR_TRUNC,
+	IPULOG_ERR_INVGR,
+	IPULOG_ERR_INVNL,
+};
+#define IPULOG_MAXERR IPULOG_ERR_INVNL
+
 #endif /* _LIBULOG_H */
